summaryrefslogtreecommitdiffstats
path: root/src/sound/AudioFileManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound/AudioFileManager.h')
-rw-r--r--src/sound/AudioFileManager.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/sound/AudioFileManager.h b/src/sound/AudioFileManager.h
index 9721669..67ae6c6 100644
--- a/src/sound/AudioFileManager.h
+++ b/src/sound/AudioFileManager.h
@@ -26,8 +26,8 @@
#include <set>
#include <map>
-#include <qpixmap.h>
-#include <qobject.h>
+#include <tqpixmap.h>
+#include <tqobject.h>
#include "AudioFile.h"
#include "XmlExportable.h"
@@ -58,7 +58,7 @@ namespace Rosegarden
typedef std::vector<AudioFile*>::const_iterator AudioFileManagerIterator;
-class AudioFileManager : public QObject, public XmlExportable
+class AudioFileManager : public TQObject, public XmlExportable
{
Q_OBJECT
public:
@@ -227,12 +227,12 @@ public:
bool withMinima);
// throw BadPeakFileException, BadAudioPathException
// Draw a fixed size (fixed by QPixmap) preview of an audio file
//
void drawPreview(AudioFileId id,
const RealTime &startTime,
const RealTime &endTime,
- QPixmap *pixmap);
+ TQPixmap *pixmap);
// throw BadPeakFileException, BadAudioPathException
// Usually used to show how an audio Segment makes up part of
@@ -243,7 +243,7 @@ public:
const RealTime &endTime,
const RealTime &highlightStart,
const RealTime &highlightEnd,
- QPixmap *pixmap);
+ TQPixmap *pixmap);
// throw BadPeakFileException, BadAudioPathException
// Get a short file name from a long one (with '/'s)
@@ -290,7 +290,7 @@ public:
signals:
void setProgress(int);
- void setOperationName(QString);
+ void setOperationName(TQString);
public slots:
// Cancel a running preview
@@ -227,12 +227,12 @@ public:
bool withMinima);
// throw BadPeakFileException, BadAudioPathException
- // Draw a fixed size (fixed by QPixmap) preview of an audio file
+ // Draw a fixed size (fixed by TQPixmap) preview of an audio file
//
void drawPreview(AudioFileId id,